
import { maker } from "f-create";
import { isNumber } from "../table-filter/util";

const componentField = {
    cascader: "cascader",
    select: "select",
    radio: "radio",
    checkbox: "checkbox",
    checkboxone: "checkbox",
    switch: "switch",
    hidden: "hidden",
    staring: "rate",
    mobile: "input",
    textarea: "input",
    text: "input",
    attachments: "upload",
    uploadImage: "uploadImage",
    uploadImageOne: "uploadImageOne",
    uploadFileOne: "uploadFileOne",
    uploadFile: "uploadFile",
    email: "input",
    process: "slider",
    money: "number",
    decimal: "number",
    number: "number",

    daterange: "dateRange",
    dateTimeRange: "dateTimeRange",
    dateTime: "dateTime",
    datetime: "dateTime",
    timeRange: "timeRange",
    year: "year",
    month: "month",
    time: "time",
    date: "date",

    treeselect: "treeselect",
    editor: "editor",
    ueditor: "ueditor"
}

/**
 * 表单数据处理类返回marker
 * 
 * @param {Array} fieldData 
 */
export const handleFormRule = (fields, changeValue, getChildOptions) => {
    return fields.filter(f => f.display == 1 || f.is_display == 1).map(field => {
        let value = field.props.default_value;
        if (isNumber(value) || value === 0) {
            value = String(value);
        } else if (Array.isArray(value)) {
            value = value.map(c => String(c))
        }
        let fieldType = componentField[field.field_type] || field.field_type;

        if (fieldType == "treeselect") {
            if (!field.props.default_value) {
                if (field.props.multiple) {
                    value = [];
                } else {
                    value = null;
                }
            }
        }

        let mk = maker[fieldType](field.title, field.field_name, value);
        setProps(mk, field);
        setValidate(mk, field);
        setOptions(mk, field, fields);
        setEvent(mk, field, changeValue, getChildOptions);
        setCustomEvent(mk, field);
        setCol(mk, field)
        return mk;
    })
}
//设置字段参数
const setProps = (marker, field) => {
    if (!isObject(field.props) && Object.keys(field.props).length > 0) {
        return;
    }
    let fieldProps = field.props || {};

    if (["textarea", "email", "date", "url"].includes(field.field_type)) {
        fieldProps.type = field.field_type;
    }

    if (field.field_type === "textarea" && !fieldProps.autosize) {
        fieldProps.autosize = {
            minRows: 5,
            maxRows: 9
        }
    }

    if (['attachments', 'uploadImageOne', 'uploadImage'].includes(field.field_type) && !fieldProps.onSuccess) {
        fieldProps.onSuccess = function (res, file) {
            file.url = res.data.imgUrl;
            file.name = res.data.fileName;
            return res.data.imgUrl;
        }
    }

    if (field.field_type === "treeselect") {
        fieldProps.options = field.options;
    }

    if (field.props.multiple) {
        fieldProps.multiple = true;
    }

    Object.keys(field.props).forEach(key => {
        if (["disabled", 'multiple', 'clearable', 'readonly', 'search', 'enter-button', 'autosize', 'number', 'autofocus', 'spellcheck', 'filterable', 'remote', 'loading', 'label-in-value', 'transfer', 'confirm', 'open', 'editable'].includes(key)) {
            fieldProps[key] = !!fieldProps[key];

        }
    })

    if (Object.keys(fieldProps).length > 0) {
        marker.props(fieldProps);
    }
}
//设置字段验证规则
const setValidate = (marker, field) => {
    if (Array.isArray(field.validate) && field.validate.length == 0) {
        return;
    }

    marker.validate(field.validate);
}
//设置字段选项
const setOptions = (marker, field, fields) => {
    if (!Array.isArray(field.options) || field.options.length == 0) {
        // console.error(field.title + " options is not array");
        return;
    }
    if (field.field_type === "treeselect") {
        return;
    }
    let options = [];

    // if (field.field_type === "select") {
    if (!field.options.find(f => !f.parent_option_value)) {
        let parentFeild = fields.find(fd => Array.isArray(fd.props.child_fields) && fd.props.child_fields.includes(field.field_name));
        if (parentFeild && parentFeild.props.default_value) {
            options = field.options.filter(fo => fo.parent_option_value == parentFeild.props.default_value).map(o => {
                return {
                    label: o.title,
                    value: String(o.value)
                }
            })
            console.log(options)
        }
    } else {
        options = field.options.map(o => {
            return {
                label: o.title,
                value: String(o.value)
            }
        })
    }
    // }

    marker.options(options);
}
const setCustomEvent = (marker, field) => {
    if (!field.event) {
        return;
    }
    marker.event(field.event)
}
//设置字段事件  目前用于级联选择的情况。
const setEvent = (marker, field, changeValue) => {
    if (field.field_type === "select" && field.props.child_fields && field.props.child_fields.length > 0) {
        marker.event({
            change: (value) => {
                changeValue(value, field);
            }
        })
    }
}
//设置栅格
const setCol = (marker, field) => {
    if (!isObject(field.props) || !field.props.col) {
        if (field.style && !field.style.single) {
            marker.col({ span: 12 });
        } else {
            marker.col({ span: 24 });
        }
        return;
    }
    let fieldPropsCol = field.props.col || {};
    marker.col(fieldPropsCol);
}

function isObject(val) {
    return val != null && typeof val === 'object' && Array.isArray(val) === false;
};

