const conditionList = [
    { name: "等于", value: 1, types: ["all"] },
    { name: "不等于", value: 2, types: ["text", "number"] },
    {
        name: "包含",
        value: 3,
        types: ["text", "position", "checkbox", "serialnumber"]
    },
    { name: "不包含", value: 4, types: ["text", "checkbox"] },
    { name: "起始字符", value: 5, types: ["text", "serialnumber"] },
    { name: "大于", value: 6, types: ["number", "time"] },
    { name: "大于等于", value: 7, types: ["number", "time"] },
    { name: "小于", value: 8, types: ["number", "time"] },
    { name: "小于等于", value: 9, types: ["number", "time"] },
    { name: "今天", value: 10, types: ["time", "daterange"] },
    { name: "昨天", value: 11, types: ["time", "daterange"] },
    { name: "本月", value: 12, types: ["time"] },
    { name: "本周", value: 26, types: ["time"] },
    { name: "上月", value: 13, types: ["time"] },
    { name: "今年", value: 14, types: ["time"] },
    { name: "去年", value: 15, types: ["time"] },
    { name: "过去多少天内", value: 16, types: ["time"] },
    { name: "过去多少天前", value: 17, types: ["time"] },
    { name: "在未来多少天内", value: 18, types: ["time"] },
    { name: "在未来多少天前", value: 19, types: ["time"] },
    // { name: "在指定日期后", value: 20, types: ["time"] },
    // { name: "在指定日期前", value: 21, types: ["time"] },
    { name: "为空", value: 22, types: ["time", "daterange"] },
    { name: "包括", value: 23, types: ["selectUser"] },
    { name: "不为空", value: 24, types: ["time", "daterange"] }
    // { name: "区间", value: 25, types: ["time", "number"] }
];

const fieldTypeToELe = {
    date: ["daterange", "time", "datetime"],
    input: [
        "money",
        "mobile",
        "number",
        "decimal",
        "textarea",
        "text",
        "attachments",
        "email",
        "position"
    ],
    select: ["droplist", "select", "radio"]
};

export function getEleByType(fieldType) {
    if (fieldTypeToELe.date.includes(fieldType)) {
        return "date";
    } else if (fieldTypeToELe.input.includes(fieldType)) {
        return "input";
    } else if (fieldTypeToELe.select.includes(fieldType)) {
        return "select";
    }
    return "";
};

export function makeConditionList(field) {
    let filterConditionList;
    switch (field.field_type) {
        case "money":
        case "number":
            filterConditionList = conditionList.filter(
                item => item.types.includes("all") || item.types.includes("number")
            );
            break;
        case "email":
        case "text":
        case "mobile":
        case "textarea": //文本
            filterConditionList = conditionList.filter(
                item => item.types.includes("all") || item.types.includes("text")
            );
            break;
        case "daterange": //时间
            filterConditionList = conditionList.filter(
                item =>
                    item.types.includes("all") || item.types.includes("daterange")
            );
            break;
        case "time":
        case "datetime":
        case "dateTime":
            filterConditionList = conditionList.filter(
                item => item.types.includes("time") && item.value != 25
            );
            break;
        case "droplist": //下拉框
        case "radio":
        case "process":
        case "staring": //评星
            filterConditionList = conditionList.filter(item =>
                item.types.includes("all")
            );
            break;
        case "select": //多选框
            filterConditionList = conditionList.filter(
                item =>
                    item.types.includes("all") || item.types.includes("checkbox")
            );
            break;
        case "images":
            break;
        case "attachments":
            filterConditionList = conditionList.filter(
                item => item.types.includes("all") || item.types.includes("text")
            );
            break;
        case "position":
            filterConditionList = conditionList.filter(item =>
                item.types.includes("position")
            );
            break;
        default:
            break;
    }
    return filterConditionList;
};

export function makeFieldUiType(field, type) {
    let startDes = "", endDes = "", showType = "none";
    if (fieldTypeToELe.date.includes(field.field_type)) {
        if ([10, 11, 12, 13, 14, 15, 22, 24].includes(type)) {

        } else if ([16, 17, 18, 19].includes(type)) {
            if (type == 16) {
                startDes = '过去';
                endDes = '天内';
            } else if (type == 17) {
                startDes = '过去';
                endDes = '天前';
            } else if (type == 18) {
                startDes = '在未来';
                endDes = '天内';
            } else if (type == 19) {
                startDes = '在未来';
                endDes = '天前';
            }
            showType = "input"
        } else {
            showType = "date"
        }
    } else if (fieldTypeToELe.input.includes(field.field_type)) {
        showType = "input";
    } else if (fieldTypeToELe.select.includes(field.field_type)) {
        showType = "select";
    }
    return {
        startDes,
        endDes,
        type: showType
    };
};

export function isNumber(value) {
    var patrn = /^(-)?\d+(\.\d+)?$/;
    if (patrn.exec(value) == null || value == "") {
        return false
    } else {
        return true
    }
}